==> haskell-hls-pragmas-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-pragmas-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-pragmas-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-pragmas-plugin-2.1.0.0-BESsRLJpUd9DNGphLSYabQ
key:                  hls-pragmas-plugin-2.1.0.0-BESsRLJpUd9DNGphLSYabQ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  07bcc2c88ed4cd97f2f41d2e64401fe9
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-pragmas-plugin
hs-libraries:         HShls-pragmas-plugin-2.1.0.0-BESsRLJpUd9DNGphLSYabQ
depends:
    base-4.17.2.1 containers-0.6.7 extra-1.7.16-KxrHBQWVwMp2M62XitBte8
    fuzzy-0.1.1.0-GNfOtxCkXhGMK2zyKmYNv ghc-9.4.8
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-pragmas-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-pragmas-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-pragmas-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-pragmas-plugin-2.1.0.0-JkNufLfeo0XAD1s7P61TuQ
key:                  hls-pragmas-plugin-2.1.0.0-JkNufLfeo0XAD1s7P61TuQ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  d28ff58e34ec5ebacbd538c50776be0f
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-pragmas-plugin
hs-libraries:         HShls-pragmas-plugin-2.1.0.0-JkNufLfeo0XAD1s7P61TuQ
depends:
    base-4.17.2.1 containers-0.6.7 extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E
    fuzzy-0.1.1.0-cmux4DoVUwHPVW3zdrnxa ghc-9.4.8
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
